@@ -39,7 +39,10 @@ class HeatClientPlugin(client_plugin.ClientPlugin):
             args['username'] = self.context.username
             args['password'] = self.context.password
 
-        return hc.Client('1', endpoint,
+        # Note: Remove 'endpoint' from args when requirements
+        # changes to python-heatclient>=1.6.0
+        return hc.Client('1', endpoint_override=endpoint,
+                         endpoint=endpoint,
                          session=self.context.keystone_session,
                          **args)
 
