@@ -182,6 +182,20 @@ class Macro(Function):
         """
         return dep_attrs(self.parsed, resource_name)
 
+    def __reduce__(self):
+        """Return a representation of the macro result suitable for pickling.
+
+        This allows the copy module (which works by pickling and then
+        unpickling objects) to copy a template. Functions in the copy will
+        return to their original (JSON) form (i.e. a single-element map).
+
+        Unlike other functions, macros are *not* preserved during a copy. The
+        the processed (but unparsed) output is returned in their place.
+        """
+        if isinstance(self.parsed, Function):
+            return self.parsed.__reduce__()
+        return type(self.parsed), (self.parsed,)
+
     def _repr_result(self):
         return repr(self.parsed)
 
@@ -269,7 +283,7 @@ def dep_attrs(snippet, resource_name):
         return snippet.dep_attrs(resource_name)
 
     elif isinstance(snippet, collections.Mapping):
-        attrs = (dep_attrs(value, resource_name) for value in snippet.items())
+        attrs = (dep_attrs(val, resource_name) for val in snippet.values())
         return itertools.chain.from_iterable(attrs)
     elif (not isinstance(snippet, six.string_types) and
           isinstance(snippet, collections.Iterable)):
