@@ -137,7 +137,8 @@ class BaseServer(stack_user.StackUser):
 
         elif (self.transport_poll_server_heat(props) or
               self.transport_zaqar_message(props)):
-            self.password = uuid.uuid4().hex
+            if self.password is None:
+                self.password = uuid.uuid4().hex
             self._create_user()
 
         self._register_access_key()
@@ -204,12 +205,6 @@ class BaseServer(stack_user.StackUser):
             self.metadata_set(new_md)
 
         updaters = []
-        server = None
-
-        if self.METADATA in prop_diff:
-            server = self.client_plugin().get_server(self.resource_id)
-            self.client_plugin().meta_update(server,
-                                             prop_diff[self.METADATA])
 
         if self.SOFTWARE_CONFIG_TRANSPORT in prop_diff:
             self._update_software_config_transport(prop_diff)
