@@ -11,7 +11,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import keystoneclient.exceptions as kc_exception
+import keystoneauth1.exceptions as kc_exception
 from oslo_log import log as logging
 
 from heat.common import exception
@@ -27,9 +27,6 @@ class StackUser(resource.Resource):
     # Subclasses create a user, and optionally keypair associated with a
     # resource in a stack. Users are created in the heat stack user domain
     # (in a project specific to the stack)
-    def __init__(self, name, json_snippet, stack):
-        super(StackUser, self).__init__(name, json_snippet, stack)
-
     def handle_create(self):
         self._create_user()
 
@@ -168,3 +165,15 @@ class StackUser(resource.Resource):
 
         for data_key in ('access_key', 'secret_key', 'credential_id'):
             self.data_delete(data_key)
+
+    def _register_access_key(self):
+        """Access is limited to this resource, which created the keypair."""
+        def access_allowed(resource_name):
+            return resource_name == self.name
+
+        if self.access_key is not None:
+            self.stack.register_access_allowed_handler(
+                self.access_key, access_allowed)
+        if self._get_user_id() is not None:
+            self.stack.register_access_allowed_handler(
+                self._get_user_id(), access_allowed)
