@@ -11,6 +11,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import weakref
+
 from oslo_serialization import jsonutils
 from requests import exceptions
 import six
@@ -31,12 +33,13 @@ REMOTE_SCHEMES = ('http', 'https')
 LOCAL_SCHEMES = ('file',)
 
 
-def generate_class_from_template(name, data, env):
+def generate_class_from_template(name, data, param_defaults):
     tmpl = template.Template(template_format.parse(data))
-    props, attrs = TemplateResource.get_schemas(tmpl, env.param_defaults)
+    props, attrs = TemplateResource.get_schemas(tmpl, param_defaults)
     cls = type(name, (TemplateResource,),
                {'properties_schema': props,
-                'attributes_schema': attrs})
+                'attributes_schema': attrs,
+                '__doc__': tmpl.t.get(tmpl.DESCRIPTION)})
     return cls
 
 
@@ -62,7 +65,8 @@ class TemplateResource(stack_resource.StackResource):
         super(TemplateResource, self).__init__(name, json_snippet, stack)
         self.resource_info = tri
         if self.validation_exception is None:
-            self._generate_schema(self.t)
+            self._generate_schema()
+            self.reparse()
 
     def _get_resource_info(self, rsrc_defn):
         try:
@@ -102,7 +106,7 @@ class TemplateResource(stack_resource.StackResource):
                 (attributes.Attributes.schema_from_outputs(
                  tmpl[tmpl.OUTPUTS])))
 
-    def _generate_schema(self, definition):
+    def _generate_schema(self):
         self._parsed_nested = None
         try:
             tmpl = template.Template(self.child_template())
@@ -115,12 +119,10 @@ class TemplateResource(stack_resource.StackResource):
         self.properties_schema, self.attributes_schema = self.get_schemas(
             tmpl, self.stack.env.param_defaults)
 
-        self.properties = definition.properties(self.properties_schema,
-                                                self.context)
         self.attributes_schema.update(self.base_attributes_schema)
-        self.attributes = attributes.Attributes(self.name,
-                                                self.attributes_schema,
-                                                self._resolve_all_attributes)
+        self.attributes = attributes.Attributes(
+            self.name, self.attributes_schema,
+            self._make_resolver(weakref.ref(self)))
 
     def child_params(self):
         """Override method of child_params for the resource.
@@ -176,7 +178,7 @@ class TemplateResource(stack_resource.StackResource):
 
     def regenerate_info_schema(self, definition):
         self._get_resource_info(definition)
-        self._generate_schema(definition)
+        self._generate_schema()
 
     def template_data(self):
         # we want to have the latest possible template.
@@ -196,7 +198,7 @@ class TemplateResource(stack_resource.StackResource):
                 reported_excp = err
 
         if t_data is None:
-            if self.nested() is not None:
+            if self.resource_id is not None:
                 t_data = jsonutils.dumps(self.nested().t.t)
 
         if t_data is not None:
@@ -288,21 +290,22 @@ class TemplateResource(stack_resource.StackResource):
             self.metadata_set(self.t.metadata())
 
     def handle_update(self, json_snippet, tmpl_diff, prop_diff):
+        self.properties = json_snippet.properties(self.properties_schema,
+                                                  self.context)
         return self.update_with_template(self.child_template(),
                                          self.child_params())
 
     def get_reference_id(self):
-        if self.nested() is None:
+        if self.resource_id is None:
             return six.text_type(self.name)
 
-        if 'OS::stack_id' in self.nested().outputs:
-            return self.nested().output('OS::stack_id')
-
-        return self.nested().identifier().arn()
+        try:
+            return self.get_output('OS::stack_id')
+        except exception.InvalidTemplateAttribute:
+            return self.nested_identifier().arn()
 
     def get_attribute(self, key, *path):
-        stack = self.nested()
-        if stack is None:
+        if self.resource_id is None:
             return None
 
         # first look for explicit resource.x.y
@@ -310,9 +313,4 @@ class TemplateResource(stack_resource.StackResource):
             return grouputils.get_nested_attrs(self, key, False, *path)
 
         # then look for normal outputs
-        if key in stack.outputs:
-            return attributes.select_from_attribute(self.get_output(key), path)
-
-        # otherwise the key must be wrong.
-        raise exception.InvalidTemplateAttribute(resource=self.name,
-                                                 key=key)
+        return attributes.select_from_attribute(self.get_output(key), path)
