@@ -12,7 +12,6 @@
 #    under the License.
 
 import contextlib
-import uuid
 
 from oslo_log import log as logging
 from oslo_utils import excutils
@@ -20,9 +19,10 @@ from oslo_utils import excutils
 from heat.common import exception
 from heat.common.i18n import _LI
 from heat.common.i18n import _LW
+from heat.common import service_utils
 from heat.objects import stack as stack_object
 from heat.objects import stack_lock as stack_lock_object
-from heat.rpc import listener_client
+
 
 LOG = logging.getLogger(__name__)
 
@@ -34,24 +34,21 @@ class StackLock(object):
         self.engine_id = engine_id
         self.listener = None
 
-    @staticmethod
-    def engine_alive(context, engine_id):
-        return listener_client.EngineListenerClient(
-            engine_id).is_alive(context)
-
-    @staticmethod
-    def generate_engine_id():
-        return str(uuid.uuid4())
-
     def get_engine_id(self):
-        return stack_lock_object.StackLock.get_engine_id(self.stack_id)
+        """Return the ID of the engine which currently holds the lock.
+
+        Returns None if there is no lock held on the stack.
+        """
+        return stack_lock_object.StackLock.get_engine_id(self.context,
+                                                         self.stack_id)
 
     def try_acquire(self):
         """Try to acquire a stack lock.
 
         Don't raise an ActionInProgress exception or try to steal lock.
         """
-        return stack_lock_object.StackLock.create(self.stack_id,
+        return stack_lock_object.StackLock.create(self.context,
+                                                  self.stack_id,
                                                   self.engine_id)
 
     def acquire(self, retry=True):
@@ -60,7 +57,8 @@ class StackLock(object):
         :param retry: When True, retry if lock was released while stealing.
         :type retry: boolean
         """
-        lock_engine_id = stack_lock_object.StackLock.create(self.stack_id,
+        lock_engine_id = stack_lock_object.StackLock.create(self.context,
+                                                            self.stack_id,
                                                             self.engine_id)
         if lock_engine_id is None:
             LOG.debug("Engine %(engine)s acquired lock on stack "
@@ -69,10 +67,10 @@ class StackLock(object):
             return
 
         stack = stack_object.Stack.get_by_id(self.context, self.stack_id,
-                                             tenant_safe=False,
-                                             show_deleted=True)
+                                             show_deleted=True,
+                                             eager_load=False)
         if (lock_engine_id == self.engine_id or
-                self.engine_alive(self.context, lock_engine_id)):
+                service_utils.engine_alive(self.context, lock_engine_id)):
             LOG.debug("Lock on stack %(stack)s is owned by engine "
                       "%(engine)s" % {'stack': self.stack_id,
                                       'engine': lock_engine_id})
@@ -83,7 +81,8 @@ class StackLock(object):
                          "%(engine)s will attempt to steal the lock"),
                      {'stack': self.stack_id, 'engine': self.engine_id})
 
-            result = stack_lock_object.StackLock.steal(self.stack_id,
+            result = stack_lock_object.StackLock.steal(self.context,
+                                                       self.stack_id,
                                                        lock_engine_id,
                                                        self.engine_id)
 
@@ -114,7 +113,8 @@ class StackLock(object):
         """Release a stack lock."""
 
         # Only the engine that owns the lock will be releasing it.
-        result = stack_lock_object.StackLock.release(self.stack_id,
+        result = stack_lock_object.StackLock.release(self.context,
+                                                     self.stack_id,
                                                      self.engine_id)
         if result is True:
             LOG.warning(_LW("Lock was already released on stack %s!"),
