@@ -42,7 +42,7 @@ LOG = logging.getLogger(__name__)
 def retry_on_conflict(func):
     wrapper = tenacity.retry(
         stop=tenacity.stop_after_attempt(11),
-        wait=tenacity.wait_random(max=0.002),
+        wait=tenacity.wait_random(max=2),
         retry=tenacity.retry_if_exception_type(
             exception.ConcurrentTransaction),
         reraise=True)
