@@ -13,7 +13,6 @@
 
 import mock
 from oslo_config import cfg
-import six
 
 from heat.common import exception
 from heat.common import short_id
@@ -126,7 +125,7 @@ class UserTest(common.HeatTestCase):
         rsrc = user.User(resource_name,
                          resource_defns[resource_name],
                          stack)
-        rsrc._store()
+        rsrc.store()
 
         self.m.StubOutWithMock(short_id, 'get_id')
         short_id.get_id(rsrc.uuid).MultipleTimes().AndReturn('aabbcc')
@@ -346,7 +345,7 @@ class AccessKeyTest(common.HeatTestCase):
         rs_data = resource_data_object.ResourceData.get_all(rsrc)
         self.assertEqual(self.fc.secret, rs_data.get('secret_key'))
         self.assertEqual(self.fc.credential_id, rs_data.get('credential_id'))
-        self.assertEqual(2, len(list(six.iterkeys(rs_data))))
+        self.assertEqual(2, len(rs_data.keys()))
 
         self.assertEqual(utils.PhysName(stack.name, 'CfnUser'),
                          rsrc.FnGetAtt('UserName'))
