@@ -11,15 +11,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from aodhclient import exceptions as aodh_exc
 from ceilometerclient import exc as ceil_exc
-from ceilometerclient.openstack.common.apiclient import exceptions as c_a_exc
 from cinderclient import exceptions as cinder_exc
 from glanceclient import exc as glance_exc
-from glanceclient.openstack.common.apiclient import exceptions as g_a_exc
 from heatclient import client as heatclient
 from heatclient import exc as heat_exc
-from keystoneclient.auth.identity import v3
-from keystoneclient import exceptions as keystone_exc
+from keystoneauth1 import exceptions as keystone_exc
+from keystoneauth1.identity import generic
 from manilaclient import exceptions as manila_exc
 import mock
 from neutronclient.common import exceptions as neutron_exc
@@ -33,6 +32,7 @@ from zaqarclient.transport import errors as zaqar_exc
 
 from heat.common import exception
 from heat.engine import clients
+from heat.engine.clients import client_exception
 from heat.engine.clients import client_plugin
 from heat.tests import common
 from heat.tests import fakes
@@ -44,12 +44,14 @@ class ClientsTest(common.HeatTestCase):
 
     def test_bad_cloud_backend(self):
         con = mock.Mock()
-        cfg.CONF.set_override('cloud_backend', 'some.weird.object')
+        cfg.CONF.set_override('cloud_backend', 'some.weird.object',
+                              enforce_type=True)
         exc = self.assertRaises(exception.Invalid, clients.Clients, con)
         self.assertIn('Invalid cloud_backend setting in heat.conf detected',
                       six.text_type(exc))
 
-        cfg.CONF.set_override('cloud_backend', 'heat.engine.clients.Clients')
+        cfg.CONF.set_override('cloud_backend', 'heat.engine.clients.Clients',
+                              enforce_type=True)
         exc = self.assertRaises(exception.Invalid, clients.Clients, con)
         self.assertIn('Invalid cloud_backend setting in heat.conf detected',
                       six.text_type(exc))
@@ -100,7 +102,7 @@ class ClientsTest(common.HeatTestCase):
 
     def test_clients_get_heat_cfn_metadata_url_conf(self):
         cfg.CONF.set_override('heat_metadata_server_url',
-                              'http://server.test:123')
+                              'http://server.test:123', enforce_type=True)
         obj = self._client_cfn_url()
         self.assertEqual("http://server.test:123/v1/",
                          obj.get_cfn_metadata_server_url())
@@ -153,7 +155,6 @@ class ClientsTest(common.HeatTestCase):
         obj.get_heat_url.return_value = None
         obj.url_for = mock.Mock(name="url_for")
         obj.url_for.return_value = "url_from_keystone"
-        obj._client = None
         heat = obj.client()
         heat_cached = obj.client()
         self.assertEqual(heat, heat_cached)
@@ -182,11 +183,11 @@ class ClientPluginTest(common.HeatTestCase):
         plugin = FooClientsPlugin(con)
 
         cfg.CONF.set_override('ca_file', '/tmp/bar',
-                              group='clients_heat')
+                              group='clients_heat', enforce_type=True)
         cfg.CONF.set_override('ca_file', '/tmp/foo',
-                              group='clients')
+                              group='clients', enforce_type=True)
         cfg.CONF.set_override('endpoint_type', 'internalURL',
-                              group='clients')
+                              group='clients', enforce_type=True)
 
         # check heat group
         self.assertEqual('/tmp/bar',
@@ -200,69 +201,6 @@ class ClientPluginTest(common.HeatTestCase):
         self.assertEqual('/tmp/foo',
                          plugin._get_client_option('foo', 'ca_file'))
 
-    def test_get_client_args(self):
-        ctxt = mock.Mock()
-        plugin = FooClientsPlugin(ctxt)
-
-        plugin.url_for = mock.Mock(return_value='sample_endpoint_url')
-        plugin.context.auth_url = 'sample_auth_url'
-        plugin.context.tenant_id = 'sample_project_id'
-
-        mock_args = {
-            'endpoint_type': 'internalURL',
-            'ca_file': '/tmp/ca_file',
-            'cert_file': '/tmp/cert_file',
-            'key_file': '/tmp/key_file',
-            'insecure': True
-        }
-
-        def _side_effect(service_name, arg_name):
-            return mock_args[arg_name]
-
-        plugin._get_client_option = mock.Mock(side_effect=_side_effect)
-
-        args = plugin._get_client_args('sample_service',
-                                       'foo_type')
-
-        self.assertEqual('foo_type',
-                         args['service_type'],
-                         'invalid service_type')
-
-        self.assertEqual('sample_auth_url',
-                         args['auth_url'],
-                         'invalid auth_url')
-
-        self.assertEqual('sample_project_id',
-                         args['project_id'],
-                         'invalid project_id')
-
-        self.assertEqual('5678',
-                         args['token'](),
-                         'invalid auth_token')
-
-        self.assertEqual('sample_endpoint_url',
-                         args['os_endpoint'],
-                         'invalid os_endpoint')
-
-        self.assertEqual('internalURL',
-                         args['endpoint_type'],
-                         'invalid endpoint_type')
-
-        self.assertEqual('/tmp/ca_file',
-                         args['cacert'],
-                         'invalid cacert')
-
-        self.assertEqual('/tmp/cert_file',
-                         args['cert_file'],
-                         'invalid cert_file')
-
-        self.assertEqual('/tmp/key_file',
-                         args['key_file'],
-                         'invalid key_file')
-
-        self.assertTrue(args['insecure'],
-                        'invalid insecure')
-
     def test_auth_token(self):
         con = mock.Mock()
         con.auth_token = "1234"
@@ -285,16 +223,16 @@ class ClientPluginTest(common.HeatTestCase):
         c = clients.Clients(con)
         con.clients = c
 
-        con.auth_plugin = mock.Mock(name="auth_plugin")
-        con.auth_plugin.get_endpoint = mock.Mock(name="get_endpoint")
-        con.auth_plugin.get_endpoint.return_value = 'http://192.0.2.1/foo'
+        con.keystone_session = mock.Mock(name="keystone_Session")
+        con.keystone_session.get_endpoint = mock.Mock(name="get_endpoint")
+        con.keystone_session.get_endpoint.return_value = 'http://192.0.2.1/foo'
         plugin = FooClientsPlugin(con)
 
         self.assertEqual('http://192.0.2.1/foo',
                          plugin.url_for(service_type='foo'))
-        self.assertTrue(con.auth_plugin.get_endpoint.called)
+        self.assertTrue(con.keystone_session.get_endpoint.called)
 
-    @mock.patch.object(v3, "Token", name="v3_token")
+    @mock.patch.object(generic, "Token", name="v3_token")
     def test_get_missing_service_catalog(self, mock_v3):
         class FakeKeystone(fakes.FakeKeystoneClient):
             def __init__(self):
@@ -307,10 +245,10 @@ class ClientPluginTest(common.HeatTestCase):
         c = clients.Clients(con)
         con.clients = c
 
-        con.auth_plugin = mock.Mock(name="auth_plugin")
+        con.keystone_session = mock.Mock(name="keystone_session")
         get_endpoint_side_effects = [
             keystone_exc.EmptyCatalog(), None, 'http://192.0.2.1/bar']
-        con.auth_plugin.get_endpoint = mock.Mock(
+        con.keystone_session.get_endpoint = mock.Mock(
             name="get_endpoint", side_effect=get_endpoint_side_effects)
 
         mock_token_obj = mock.Mock()
@@ -322,7 +260,7 @@ class ClientPluginTest(common.HeatTestCase):
         self.assertEqual('http://192.0.2.1/bar',
                          plugin.url_for(service_type='bar'))
 
-    @mock.patch.object(v3, "Token", name="v3_token")
+    @mock.patch.object(generic, "Token", name="v3_token")
     def test_endpoint_not_found(self, mock_v3):
         class FakeKeystone(fakes.FakeKeystoneClient):
             def __init__(self):
@@ -335,15 +273,18 @@ class ClientPluginTest(common.HeatTestCase):
         c = clients.Clients(con)
         con.clients = c
 
-        con.auth_plugin = mock.Mock(name="auth_plugin")
+        con.keystone_session = mock.Mock(name="keystone_session")
         get_endpoint_side_effects = [keystone_exc.EmptyCatalog(), None]
-        con.auth_plugin.get_endpoint = mock.Mock(
+        con.keystone_session.get_endpoint = mock.Mock(
             name="get_endpoint", side_effect=get_endpoint_side_effects)
 
         mock_token_obj = mock.Mock()
         mock_v3.return_value = mock_token_obj
-        mock_token_obj.get_auth_ref.return_value = {'no_catalog': 'without'}
-
+        mock_access = mock.Mock()
+        self.patchobject(mock_token_obj, 'get_access',
+                         return_value=mock_access)
+        self.patchobject(mock_access, 'has_service_catalog',
+                         return_value=False)
         plugin = FooClientsPlugin(con)
 
         self.assertRaises(keystone_exc.EndpointNotFound,
@@ -357,21 +298,31 @@ class ClientPluginTest(common.HeatTestCase):
         self.assertRaises(TypeError, client_plugin.ClientPlugin, c)
 
     def test_create_client_on_token_expiration(self):
-        cfg.CONF.set_override('reauthentication_auth_method', 'trusts')
-        con = mock.Mock()
-        con.auth_plugin.auth_ref.will_expire_soon.return_value = False
+        cfg.CONF.set_override('reauthentication_auth_method', 'trusts',
+                              enforce_type=True)
+        con = utils.dummy_context()
+        auth_ref = mock.Mock()
+        self.patchobject(con.auth_plugin, 'get_auth_ref',
+                         return_value=auth_ref)
+        auth_ref.will_expire_soon.return_value = False
         plugin = FooClientsPlugin(con)
         plugin._create = mock.Mock()
         plugin.client()
         self.assertEqual(1, plugin._create.call_count)
         plugin.client()
         self.assertEqual(1, plugin._create.call_count)
-        con.auth_plugin.auth_ref.will_expire_soon.return_value = True
+        auth_ref.will_expire_soon.return_value = True
         plugin.client()
         self.assertEqual(2, plugin._create.call_count)
 
     def test_create_client_on_invalidate(self):
-        con = mock.Mock()
+        cfg.CONF.set_override('reauthentication_auth_method', 'trusts',
+                              enforce_type=True)
+        con = utils.dummy_context()
+        auth_ref = mock.Mock()
+        self.patchobject(con.auth_plugin, 'get_auth_ref',
+                         return_value=auth_ref)
+        auth_ref.will_expire_soon.return_value = False
         plugin = FooClientsPlugin(con)
         plugin._create = mock.Mock()
         plugin.client()
@@ -411,11 +362,11 @@ class TestClientPluginsInitialise(common.HeatTestCase):
             self.assertIsNotNone(plugin)
             self.assertEqual(c, plugin.clients)
             self.assertEqual(con, plugin.context)
-            self.assertIsNone(plugin._client)
+            self.assertEqual({}, plugin._client_instances)
             self.assertTrue(clients.has_client(plugin_name))
             self.assertIsInstance(plugin.service_types, list)
-            self.assertTrue(len(plugin.service_types) >= 1,
-                            'service_types is not defined for plugin')
+            self.assertGreaterEqual(len(plugin.service_types), 1,
+                                    'service_types is not defined for plugin')
 
     @mock.patch.object(client_plugin.ClientPlugin, 'invalidate')
     def test_invalidate_all_clients(self, mock_invalidate):
@@ -427,7 +378,9 @@ class TestClientPluginsInitialise(common.HeatTestCase):
             plugin = c.client_plugin(plugin_name)
             self.assertIsNotNone(plugin)
         c.invalidate_plugins()
-        self.assertEqual(len(plugin_types), mock_invalidate.call_count)
+        # while client plugin is initialized and while client is invoked
+        # its being invalidated, so the count will be doubled
+        self.assertEqual(len(plugin_types) * 2, mock_invalidate.call_count)
 
 
 class TestIsNotFound(common.HeatTestCase):
@@ -441,14 +394,6 @@ class TestIsNotFound(common.HeatTestCase):
             plugin='ceilometer',
             exception=lambda: ceil_exc.HTTPNotFound(details='gone'),
         )),
-        ('ceilometer_not_found_apiclient', dict(
-            is_not_found=True,
-            is_over_limit=False,
-            is_client_exception=True,
-            is_conflict=False,
-            plugin='ceilometer',
-            exception=lambda: c_a_exc.NotFound(details='gone'),
-        )),
         ('ceilometer_exception', dict(
             is_not_found=False,
             is_over_limit=False,
@@ -473,6 +418,30 @@ class TestIsNotFound(common.HeatTestCase):
             plugin='ceilometer',
             exception=lambda: ceil_exc.HTTPConflict(),
         )),
+        ('aodh_not_found', dict(
+            is_not_found=True,
+            is_over_limit=False,
+            is_client_exception=True,
+            is_conflict=False,
+            plugin='aodh',
+            exception=lambda: aodh_exc.NotFound('not found'),
+        )),
+        ('aodh_overlimit', dict(
+            is_not_found=False,
+            is_over_limit=True,
+            is_client_exception=True,
+            is_conflict=False,
+            plugin='aodh',
+            exception=lambda: aodh_exc.OverLimit('over'),
+        )),
+        ('aodh_conflict', dict(
+            is_not_found=False,
+            is_over_limit=False,
+            is_client_exception=True,
+            is_conflict=True,
+            plugin='aodh',
+            exception=lambda: aodh_exc.Conflict('conflict'),
+        )),
         ('cinder_not_found', dict(
             is_not_found=True,
             is_over_limit=False,
@@ -512,7 +481,7 @@ class TestIsNotFound(common.HeatTestCase):
             is_client_exception=True,
             is_conflict=False,
             plugin='glance',
-            exception=lambda: g_a_exc.NotFound(),
+            exception=lambda: client_exception.EntityMatchNotFound(),
         )),
         ('glance_not_found_2', dict(
             is_not_found=True,
@@ -538,14 +507,6 @@ class TestIsNotFound(common.HeatTestCase):
             plugin='glance',
             exception=lambda: glance_exc.HTTPOverLimit(details='over'),
         )),
-        ('glance_conflict_1', dict(
-            is_not_found=False,
-            is_over_limit=False,
-            is_client_exception=True,
-            is_conflict=True,
-            plugin='glance',
-            exception=lambda: g_a_exc.Conflict(),
-        )),
         ('glance_conflict_1', dict(
             is_not_found=False,
             is_over_limit=False,
@@ -997,24 +958,3 @@ class TestIsNotFound(common.HeatTestCase):
                 iue = self.is_unprocessable_entity
                 if iue != client_plugin.is_unprocessable_entity(e):
                     raise
-
-
-class ClientAPIVersionTest(common.HeatTestCase):
-
-    def test_cinder_api_v1_and_v2(self):
-        self.stub_auth()
-        ctx = utils.dummy_context()
-        client = clients.Clients(ctx).client('cinder')
-        self.assertEqual(2, client.volume_api_version)
-
-    def test_cinder_api_v1_only(self):
-        self.stub_auth(only_services=['volume'])
-        ctx = utils.dummy_context()
-        client = clients.Clients(ctx).client('cinder')
-        self.assertEqual(1, client.volume_api_version)
-
-    def test_cinder_api_v2_only(self):
-        self.stub_auth(only_services=['volumev2'])
-        ctx = utils.dummy_context()
-        client = clients.Clients(ctx).client('cinder')
-        self.assertEqual(2, client.volume_api_version)
