@@ -688,65 +688,51 @@ class HeatMigrationsCheckers(test_migrations.WalkVersionsMixin,
         self.assertColumnNotExists(engine, 'raw_template',
                                    'predecessor')
 
-    def _pre_upgrade_065(self, engine):
-        raw_template = utils.get_table(engine, 'raw_template')
-        templ = []
-        for i in range(960, 963, 1):
-            t = dict(id=i, template='{}', files='{}')
-            engine.execute(raw_template.insert(), [t])
-            templ.append(t)
-
-        user_creds = utils.get_table(engine, 'user_creds')
-        user = [dict(id=uid, username='test_user', password='password',
-                     tenant='test_project', auth_url='bla',
-                     tenant_id=str(uuid.uuid4()),
-                     trust_id='',
-                     trustor_user_id='') for uid in range(960, 963)]
-        engine.execute(user_creds.insert(), user)
-
-        stack = utils.get_table(engine, 'stack')
-        root_sid = '9a6a3ddb-2219-452c-8fec-a4977f8fe474'
-        stack_ids = [(root_sid, 0, None),
-                     ('b6a23bc2-cd4e-496f-be2e-c11d06124ea2', 1, root_sid),
-                     ('7a927947-e004-4afa-8d11-62c1e049ecbd', 2, root_sid)]
-        data = [dict(id=ll_id, name=ll_id,
-                     owner_id=owner_id,
-                     raw_template_id=templ[templ_id]['id'],
-                     user_creds_id=user[templ_id]['id'],
-                     username='test_user',
-                     disable_rollback=True,
-                     parameters='test_params',
-                     created_at=timeutils.utcnow(),
-                     deleted_at=None)
-                for ll_id, templ_id, owner_id in stack_ids]
-
-        engine.execute(stack.insert(), data)
-
-        res_table = utils.get_table(engine, 'resource')
-        resource_ids = [(960, root_sid),
-                        (961, 'b6a23bc2-cd4e-496f-be2e-c11d06124ea2'),
-                        (962, '7a927947-e004-4afa-8d11-62c1e049ecbd')]
-        resources = [dict(id=rid, stack_id=sid)
-                     for rid, sid in resource_ids]
-        engine.execute(res_table.insert(), resources)
-
     def _check_065(self, engine, data):
         self.assertColumnExists(engine, 'resource', 'root_stack_id')
-        res_table = utils.get_table(engine, 'resource')
-        res_in_db = list(res_table.select().execute())
-        self.assertTrue(len(res_in_db) >= 3)
-        # confirm the resource.root_stack_id is set for all resources
-        for r in res_in_db:
-            self.assertTrue(r.root_stack_id is not None)
-            if r.id >= 960 and r.id <= 962:
-                root_stack_id = '9a6a3ddb-2219-452c-8fec-a4977f8fe474'
-                self.assertEqual(root_stack_id, r.root_stack_id)
+        self.assertIndexExists(engine, 'resource', 'ix_resource_root_stack_id')
 
     def _check_071(self, engine, data):
         self.assertIndexExists(engine, 'stack', 'ix_stack_owner_id')
         self.assertIndexMembers(engine, 'stack', 'ix_stack_owner_id',
                                 ['owner_id'])
 
+    def _check_073(self, engine, data):
+        # check if column still exists and is not nullable.
+        self.assertColumnIsNotNullable(engine, 'resource_data', 'resource_id')
+        # Ensure that only one foreign key exists and is created as expected.
+        inspector = sqlalchemy.engine.reflection.Inspector.from_engine(engine)
+        resource_data_fkeys = inspector.get_foreign_keys('resource_data')
+        self.assertEqual(1, len(resource_data_fkeys))
+        fk = resource_data_fkeys[0]
+        self.assertEqual('fk_resource_id', fk['name'])
+        self.assertEqual(['resource_id'], fk['constrained_columns'])
+        self.assertEqual('resource', fk['referred_table'])
+        self.assertEqual(['id'], fk['referred_columns'])
+
+    def _check_079(self, engine, data):
+        self.assertColumnExists(engine, 'resource',
+                                'rsrc_prop_data_id')
+        self.assertColumnExists(engine, 'event',
+                                'rsrc_prop_data_id')
+        column_list = [('id', False),
+                       ('data', True),
+                       ('encrypted', True),
+                       ('updated_at', True),
+                       ('created_at', True)]
+
+        for column in column_list:
+            self.assertColumnExists(engine,
+                                    'resource_properties_data', column[0])
+            if not column[1]:
+                self.assertColumnIsNotNullable(engine,
+                                               'resource_properties_data',
+                                               column[0])
+            else:
+                self.assertColumnIsNullable(engine,
+                                            'resource_properties_data',
+                                            column[0])
+
 
 class TestHeatMigrationsMySQL(HeatMigrationsCheckers,
                               test_base.MySQLOpportunisticTestCase):
