@@ -40,7 +40,7 @@ class ServiceEngineTest(common.HeatTestCase):
 
     def test_make_sure_rpc_version(self):
         self.assertEqual(
-            '1.26',
+            '1.35',
             service.EngineService.RPC_API_VERSION,
             ('RPC version is changed, please update this test to new version '
              'and make sure additional test cases are added for RPC APIs '
@@ -222,7 +222,7 @@ class ServiceEngineTest(common.HeatTestCase):
                 return_value=mock.Mock())
     @mock.patch('heat.common.messaging.get_rpc_client',
                 return_value=mock.Mock())
-    @mock.patch('heat.engine.stack_lock.StackLock.generate_engine_id',
+    @mock.patch('heat.common.service_utils.generate_engine_id',
                 return_value='sample-uuid')
     @mock.patch('heat.engine.service.ThreadGroupManager',
                 return_value=mock.Mock())
@@ -259,7 +259,7 @@ class ServiceEngineTest(common.HeatTestCase):
                 return_value=mock.Mock())
     @mock.patch('heat.common.messaging.get_rpc_client',
                 return_value=mock.Mock())
-    @mock.patch('heat.engine.stack_lock.StackLock.generate_engine_id',
+    @mock.patch('heat.common.service_utils.generate_engine_id',
                 return_value=mock.Mock())
     @mock.patch('heat.engine.service.ThreadGroupManager',
                 return_value=mock.Mock())
@@ -329,7 +329,7 @@ class ServiceEngineTest(common.HeatTestCase):
             self.eng.thread_group_mgr.stop.assert_has_calls(calls, True)
 
             # # Manage Thread group
-            self.eng.manage_thread_grp.stop.assert_called_with(False)
+            self.eng.manage_thread_grp.stop.assert_called_with()
 
             # Service delete
             admin_context_method.assert_called_once_with()
@@ -389,7 +389,7 @@ class ServiceEngineTest(common.HeatTestCase):
                 return_value=mock.Mock())
     @mock.patch('heat.common.messaging.get_rpc_client',
                 return_value=mock.Mock())
-    @mock.patch('heat.engine.stack_lock.StackLock.generate_engine_id',
+    @mock.patch('heat.common.service_utils.generate_engine_id',
                 return_value=mock.Mock())
     @mock.patch('heat.engine.service.ThreadGroupManager',
                 return_value=mock.Mock())
@@ -411,50 +411,3 @@ class ServiceEngineTest(common.HeatTestCase):
         self.eng.start()
         self.assertEqual(cfg.CONF.executor_thread_pool_size,
                          cfg.CONF.database.max_overflow)
-
-    def test_merge_environments(self):
-        # Setup
-        params = {'parameters': {
-            'p0': 'CORRECT',
-            'p1': 'INCORRECT',
-            'p2': 'INCORRECT'}
-        }
-        env_1 = '''
-        {'parameters' : {
-            'p1': 'CORRECT',
-            'p2': 'INCORRECT-ENV-1',
-        }}'''
-        env_2 = '''
-        {'parameters': {
-            'p2': 'CORRECT'
-        }}'''
-
-        files = {'env_1': env_1, 'env_2': env_2}
-        environment_files = ['env_1', 'env_2']
-
-        # Test
-        self.eng._merge_environments(environment_files, files, params)
-
-        # Verify
-        expected = {'parameters': {
-            'p0': 'CORRECT',
-            'p1': 'CORRECT',
-            'p2': 'CORRECT',
-        }}
-        self.assertEqual(expected, params)
-
-    def test_merge_environments_no_env_files(self):
-        params = {'parameters': {'p0': 'CORRECT'}}
-        env_1 = '''
-        {'parameters' : {
-            'p0': 'INCORRECT',
-        }}'''
-
-        files = {'env_1': env_1}
-
-        # Test - Should ignore env_1 in files
-        self.eng._merge_environments(None, files, params)
-
-        # Verify
-        expected = {'parameters': {'p0': 'CORRECT'}}
-        self.assertEqual(expected, params)
