@@ -16,6 +16,7 @@ from oslo_messaging.rpc import dispatcher
 from oslo_service import threadgroup
 import six
 
+from heat.common import environment_util as env_util
 from heat.common import exception
 from heat.engine.clients.os import glance
 from heat.engine.clients.os import nova
@@ -54,7 +55,7 @@ class StackCreateTest(common.HeatTestCase):
         mock_env = self.patchobject(environment, 'Environment',
                                     return_value=stk.env)
         mock_stack = self.patchobject(stack, 'Stack', return_value=stk)
-        mock_merge = self.patchobject(self.man, '_merge_environments')
+        mock_merge = self.patchobject(env_util, 'merge_environments')
         result = self.man.create_stack(self.ctx, stack_name,
                                        template, params, None, {},
                                        environment_files=environment_files)
@@ -62,17 +63,16 @@ class StackCreateTest(common.HeatTestCase):
         self.assertIsInstance(result, dict)
         self.assertTrue(result['stack_id'])
 
-        mock_tmpl.assert_called_once_with(template, files=None, env=stk.env)
+        mock_tmpl.assert_called_once_with(template, files=None)
         mock_env.assert_called_once_with(params)
-        mock_stack.assert_called_once_with(self.ctx, stack_name, stk.t,
-                                           owner_id=None, nested_depth=0,
-                                           user_creds_id=None,
-                                           stack_user_project_id=None,
-                                           convergence=False,
-                                           parent_resource=None)
+        mock_stack.assert_called_once_with(
+            self.ctx, stack_name, stk.t, owner_id=None, nested_depth=0,
+            user_creds_id=None, stack_user_project_id=None,
+            convergence=cfg.CONF.convergence_engine, parent_resource=None)
 
         if environment_files:
-            mock_merge.assert_called_once_with(environment_files, None, params)
+            mock_merge.assert_called_once_with(environment_files, None,
+                                               params, mock.ANY)
         mock_validate.assert_called_once_with()
 
     def test_stack_create(self):
@@ -86,12 +86,12 @@ class StackCreateTest(common.HeatTestCase):
                                 environment_files=environment_files)
 
     def test_stack_create_equals_max_per_tenant(self):
-        cfg.CONF.set_override('max_stacks_per_tenant', 1)
+        cfg.CONF.set_override('max_stacks_per_tenant', 1, enforce_type=True)
         stack_name = 'service_create_test_stack_equals_max'
         self._test_stack_create(stack_name)
 
     def test_stack_create_exceeds_max_per_tenant(self):
-        cfg.CONF.set_override('max_stacks_per_tenant', 0)
+        cfg.CONF.set_override('max_stacks_per_tenant', 0, enforce_type=True)
         stack_name = 'service_create_test_stack_exceeds_max'
         ex = self.assertRaises(dispatcher.ExpectedException,
                                self._test_stack_create, stack_name)
@@ -120,14 +120,12 @@ class StackCreateTest(common.HeatTestCase):
                                None, {})
         self.assertEqual(exception.StackValidationFailed, ex.exc_info[0])
 
-        mock_tmpl.assert_called_once_with(template, files=None, env=stk.env)
+        mock_tmpl.assert_called_once_with(template, files=None)
         mock_env.assert_called_once_with(params)
-        mock_stack.assert_called_once_with(self.ctx, stack_name, stk.t,
-                                           owner_id=None, nested_depth=0,
-                                           user_creds_id=None,
-                                           stack_user_project_id=None,
-                                           convergence=False,
-                                           parent_resource=None)
+        mock_stack.assert_called_once_with(
+            self.ctx, stack_name, stk.t, owner_id=None, nested_depth=0,
+            user_creds_id=None, stack_user_project_id=None,
+            convergence=cfg.CONF.convergence_engine, parent_resource=None)
 
     def test_stack_create_invalid_stack_name(self):
         stack_name = 'service_create_test_stack_invalid_name'
@@ -186,14 +184,12 @@ class StackCreateTest(common.HeatTestCase):
         self.assertEqual('Missing required credential: X-Auth-Key',
                          six.text_type(ex.exc_info[1]))
 
-        mock_tmpl.assert_called_once_with(template, files=None, env=stk.env)
+        mock_tmpl.assert_called_once_with(template, files=None)
         mock_env.assert_called_once_with(params)
-        mock_stack.assert_called_once_with(ctx_no_pwd, stack_name, stk.t,
-                                           owner_id=None, nested_depth=0,
-                                           user_creds_id=None,
-                                           stack_user_project_id=None,
-                                           convergence=False,
-                                           parent_resource=None)
+        mock_stack.assert_called_once_with(
+            ctx_no_pwd, stack_name, stk.t, owner_id=None, nested_depth=0,
+            user_creds_id=None, stack_user_project_id=None,
+            convergence=cfg.CONF.convergence_engine, parent_resource=None)
         mock_tmpl.reset_mock()
         mock_env.reset_mock()
         mock_stack.reset_mock()
@@ -209,14 +205,12 @@ class StackCreateTest(common.HeatTestCase):
         self.assertEqual('Missing required credential: X-Auth-User',
                          six.text_type(ex.exc_info[1]))
 
-        mock_tmpl.assert_called_once_with(template, files=None, env=stk.env)
+        mock_tmpl.assert_called_once_with(template, files=None)
         mock_env.assert_called_once_with(params)
-        mock_stack.assert_called_once_with(ctx_no_user, stack_name, stk.t,
-                                           owner_id=None, nested_depth=0,
-                                           user_creds_id=None,
-                                           stack_user_project_id=None,
-                                           convergence=False,
-                                           parent_resource=None)
+        mock_stack.assert_called_once_with(
+            ctx_no_user, stack_name, stk.t, owner_id=None, nested_depth=0,
+            user_creds_id=None, stack_user_project_id=None,
+            convergence=cfg.CONF.convergence_engine, parent_resource=None)
 
     @mock.patch.object(stack_object.Stack, 'count_total_resources')
     def test_stack_create_total_resources_equals_max(self, ctr):
@@ -240,19 +234,17 @@ class StackCreateTest(common.HeatTestCase):
                                     return_value=stk.env)
         mock_stack = self.patchobject(stack, 'Stack', return_value=stk)
 
-        cfg.CONF.set_override('max_resources_per_stack', 3)
+        cfg.CONF.set_override('max_resources_per_stack', 3, enforce_type=True)
 
         result = self.man.create_stack(self.ctx, stack_name, template, params,
                                        None, {})
 
-        mock_tmpl.assert_called_once_with(template, files=None, env=stk.env)
+        mock_tmpl.assert_called_once_with(template, files=None)
         mock_env.assert_called_once_with(params)
-        mock_stack.assert_called_once_with(self.ctx, stack_name, stk.t,
-                                           owner_id=None, nested_depth=0,
-                                           user_creds_id=None,
-                                           stack_user_project_id=None,
-                                           convergence=False,
-                                           parent_resource=None)
+        mock_stack.assert_called_once_with(
+            self.ctx, stack_name, stk.t, owner_id=None, nested_depth=0,
+            user_creds_id=None, stack_user_project_id=None,
+            convergence=cfg.CONF.convergence_engine, parent_resource=None)
 
         self.assertEqual(stk.identifier(), result)
         root_stack_id = stk.root_stack_id()
@@ -272,7 +264,7 @@ class StackCreateTest(common.HeatTestCase):
             }
         }
 
-        cfg.CONF.set_override('max_resources_per_stack', 2)
+        cfg.CONF.set_override('max_resources_per_stack', 2, enforce_type=True)
         ex = self.assertRaises(dispatcher.ExpectedException,
                                self.man.create_stack, self.ctx, stack_name,
                                tpl, params, None, {})
@@ -280,6 +272,40 @@ class StackCreateTest(common.HeatTestCase):
         self.assertIn(exception.StackResourceLimitExceeded.msg_fmt,
                       six.text_type(ex.exc_info[1]))
 
+    @mock.patch.object(threadgroup, 'ThreadGroup')
+    @mock.patch.object(stack.Stack, 'validate')
+    def test_stack_create_nested(self, mock_validate, mock_tg):
+        convergence_engine = cfg.CONF.convergence_engine
+        stack_name = 'service_create_nested_test_stack'
+        parent_stack = tools.get_stack(stack_name + '_parent', self.ctx)
+        owner_id = parent_stack.store()
+        mock_tg.return_value = tools.DummyThreadGroup()
+
+        stk = tools.get_stack(stack_name, self.ctx, with_params=True,
+                              owner_id=owner_id, nested_depth=1)
+        tmpl_id = stk.t.store(self.ctx)
+
+        mock_load = self.patchobject(templatem.Template, 'load',
+                                     return_value=stk.t)
+        mock_stack = self.patchobject(stack, 'Stack', return_value=stk)
+        result = self.man.create_stack(self.ctx, stack_name, None,
+                                       None, None, {},
+                                       owner_id=owner_id, nested_depth=1,
+                                       template_id=tmpl_id)
+        self.assertEqual(stk.identifier(), result)
+        self.assertIsInstance(result, dict)
+        self.assertTrue(result['stack_id'])
+
+        mock_load.assert_called_once_with(self.ctx, tmpl_id)
+        mock_stack.assert_called_once_with(self.ctx, stack_name, stk.t,
+                                           owner_id=owner_id, nested_depth=1,
+                                           user_creds_id=None,
+                                           stack_user_project_id=None,
+                                           convergence=convergence_engine,
+                                           parent_resource=None)
+
+        mock_validate.assert_called_once_with()
+
     def test_stack_validate(self):
         stack_name = 'stack_create_test_validate'
         stk = tools.get_stack(stack_name, self.ctx)
@@ -354,6 +380,6 @@ class StackCreateTest(common.HeatTestCase):
     def test_stack_create_max_unlimited(self, total_res_mock, validate_mock):
         total_res_mock.return_value = 9999
         validate_mock.return_value = None
-        cfg.CONF.set_override('max_resources_per_stack', -1)
+        cfg.CONF.set_override('max_resources_per_stack', -1, enforce_type=True)
         stack_name = 'service_create_test_max_unlimited'
         self._test_stack_create(stack_name)
