@@ -43,11 +43,14 @@ class ResourceTypeTest(common.HeatTestCase):
                                             mock_is_service_available):
         mock_is_service_available.return_value = (True, None)
         resources = self.eng.list_resource_types(self.ctx, "DEPRECATED")
-        self.assertEqual(set(['OS::Heat::HARestarter',
+        self.assertEqual(set(['OS::Designate::Domain',
+                              'OS::Designate::Record',
+                              'OS::Heat::HARestarter',
                               'OS::Neutron::HealthMonitor',
                               'OS::Neutron::LoadBalancer',
                               'OS::Neutron::Pool',
                               'OS::Neutron::PoolMember',
+                              'OS::Glance::Image',
                               'OS::Aodh::CombinationAlarm']),
                          set(resources))
 
