@@ -18,8 +18,9 @@ wrong the tests might raise AssertionError. I've indicated in comments the
 places where actual behavior differs from the spec.
 """
 
-from keystoneclient import auth
-from keystoneclient import session
+from keystoneauth1 import plugin
+from keystoneauth1 import session
+import mock
 
 from heat.common import context
 
@@ -73,7 +74,7 @@ class FakeClient(object):
         pass
 
 
-class FakeAuth(auth.BaseAuthPlugin):
+class FakeAuth(plugin.BaseAuthPlugin):
 
     def __init__(self, auth_token='abcd1234', only_services=None):
         self.auth_token = auth_token
@@ -89,6 +90,10 @@ class FakeAuth(auth.BaseAuthPlugin):
 
         return 'http://example.com:1234/v1'
 
+    def get_auth_ref(self, session):
+        auth_ref = mock.Mock()
+        return auth_ref
+
 
 class FakeKeystoneClient(object):
     def __init__(self, username='test_username', password='password',
