@@ -166,7 +166,8 @@ class CinderVolumeTest(vt_base.BaseVolumeTest):
             description='ImageVolumeDescription',
             name='ImageVolume',
             imageRef=image_id,
-            multiattach=False).AndReturn(fv)
+            multiattach=False,
+            metadata={}).AndReturn(fv)
         self.cinder_fc.volumes.get(fv.id).AndReturn(fv)
         fv_ready = vt_base.FakeVolume('available', id=fv.id)
         self.cinder_fc.volumes.get(fv.id).AndReturn(fv_ready)
@@ -195,7 +196,8 @@ class CinderVolumeTest(vt_base.BaseVolumeTest):
             size=1, availability_zone='nova',
             description='ImageVolumeDescription',
             name='ImageVolume',
-            multiattach=False).AndReturn(fv)
+            multiattach=False,
+            metadata={}).AndReturn(fv)
 
         update_readonly_mock = self.patchobject(self.cinder_fc.volumes,
                                                 'update_readonly_flag')
@@ -230,7 +232,8 @@ class CinderVolumeTest(vt_base.BaseVolumeTest):
             size=1, availability_zone='nova',
             description=None,
             name=vol_name,
-            multiattach=False
+            multiattach=False,
+            metadata={}
         ).AndReturn(fv)
         self.cinder_fc.volumes.get(fv.id).AndReturn(fv)
         fv_ready = vt_base.FakeVolume('available', id=fv.id)
@@ -621,6 +624,50 @@ class CinderVolumeTest(vt_base.BaseVolumeTest):
 
         update_readonly_mock.assert_called_once_with(fv.id, True)
 
+    def test_cinder_volume_update_no_need_replace(self):
+        # update read only access mode
+        fv = vt_base.FakeVolume('creating')
+        stack_name = 'test_update_no_need_replace'
+        cinder.CinderClientPlugin._create().AndReturn(
+            self.cinder_fc)
+
+        vol_name = utils.PhysName(stack_name, 'volume2')
+        self.cinder_fc.volumes.create(
+            size=2, availability_zone='nova',
+            description=None,
+            name=vol_name,
+            multiattach=False,
+            metadata={}
+        ).AndReturn(fv)
+
+        fv_ready = vt_base.FakeVolume('available', id=fv.id, size=2,
+                                      attachments=[])
+        self.cinder_fc.volumes.get(fv.id).MultipleTimes().AndReturn(fv_ready)
+        self.cinder_fc.volumes.extend(fv.id, 3)
+
+        self.m.ReplayAll()
+
+        stack = utils.parse_stack(self.t, stack_name=stack_name)
+
+        rsrc = self.create_volume(self.t, stack, 'volume2')
+
+        props = copy.deepcopy(rsrc.properties.data)
+        props['size'] = 1
+        after = rsrc_defn.ResourceDefinition(rsrc.name, rsrc.type(), props)
+        update_task = scheduler.TaskRunner(rsrc.update, after)
+        ex = self.assertRaises(exception.ResourceFailure, update_task)
+        self.assertEqual((rsrc.UPDATE, rsrc.FAILED), rsrc.state)
+        self.assertIn("NotSupported: resources.volume2: Shrinking volume is "
+                      "not supported", six.text_type(ex))
+
+        props = copy.deepcopy(rsrc.properties.data)
+        props['size'] = 3
+        after = rsrc_defn.ResourceDefinition(rsrc.name, rsrc.type(), props)
+        scheduler.TaskRunner(rsrc.update, after)()
+
+        self.assertEqual((rsrc.UPDATE, rsrc.COMPLETE), rsrc.state)
+        self.m.VerifyAll()
+
     def _update_if_attached(self, stack_name, update_type='resize'):
         # create script
         self.stub_VolumeConstraint_validate()
@@ -704,7 +751,8 @@ class CinderVolumeTest(vt_base.BaseVolumeTest):
             size=1, availability_zone=None,
             description='test_description',
             name='test_name',
-            multiattach=False
+            multiattach=False,
+            metadata={}
         ).AndReturn(vt_base.FakeVolume('creating'))
         fv = vt_base.FakeVolume('available')
         self.cinder_fc.volumes.get(fv.id).AndReturn(fv)
@@ -743,7 +791,8 @@ class CinderVolumeTest(vt_base.BaseVolumeTest):
             size=1, availability_zone=None,
             description='test_description',
             name='test_name',
-            multiattach=False
+            multiattach=False,
+            metadata={}
         ).AndReturn(vt_base.FakeVolume('creating'))
         fv = vt_base.FakeVolume('available')
         self.cinder_fc.volumes.get(fv.id).AndReturn(fv)
@@ -832,7 +881,8 @@ class CinderVolumeTest(vt_base.BaseVolumeTest):
             size=2, availability_zone='nova',
             description=None,
             name=vol2_name,
-            multiattach=False
+            multiattach=False,
+            metadata={}
         ).AndReturn(fv2)
         self.cinder_fc.volumes.get(fv2.id).AndReturn(fv2)
         fv2 = vt_base.FakeVolume('available', id=fv2.id)
@@ -949,7 +999,8 @@ class CinderVolumeTest(vt_base.BaseVolumeTest):
             size=1, name='test_name', description=None,
             availability_zone='nova',
             scheduler_hints={'hint1': 'good_advice'},
-            multiattach=False
+            multiattach=False,
+            metadata={}
         ).AndReturn(fv)
         self.cinder_fc.volumes.get(fv.id).AndReturn(fv)
         fv_ready = vt_base.FakeVolume('available', id=fv.id)
@@ -971,7 +1022,8 @@ class CinderVolumeTest(vt_base.BaseVolumeTest):
         self.cinder_fc.volumes.create(
             size=1, name='test_name', description=None,
             availability_zone='nova',
-            multiattach=True).AndReturn(fv)
+            multiattach=True,
+            metadata={}).AndReturn(fv)
         self.cinder_fc.volumes.get(fv.id).AndReturn(fv)
         fv_ready = vt_base.FakeVolume('available', id=fv.id)
         self.cinder_fc.volumes.get(fv.id).AndReturn(fv_ready)
@@ -1004,6 +1056,7 @@ class CinderVolumeTest(vt_base.BaseVolumeTest):
         self.cinder_fc.volumes.create(
             size=1, name='test_name', description='test_description',
             availability_zone=None,
+            metadata={},
             multiattach=False,
             scheduler_hints={shm.HEAT_ROOT_STACK_ID: stack.root_stack_id(),
                              shm.HEAT_STACK_ID: stack.id,
@@ -1019,7 +1072,7 @@ class CinderVolumeTest(vt_base.BaseVolumeTest):
         self.patchobject(rsrc, '_store_config_default_properties')
         scheduler.TaskRunner(rsrc.create)()
         # this makes sure the auto increment worked on volume creation
-        self.assertTrue(rsrc.id > 0)
+        self.assertGreater(rsrc.id, 0)
 
         self.m.VerifyAll()
 
@@ -1036,14 +1089,15 @@ class CinderVolumeTest(vt_base.BaseVolumeTest):
     def test_cinder_create_with_image_and_imageRef(self):
         stack_name = 'test_create_with_image_and_imageRef'
         combinations = {'imageRef': 'image-456', 'image': 'image-123'}
-        err_msg = ("Cannot define the following properties at the same time: "
+        err_msg = ("Property error: resources.volume2.properties: Cannot "
+                   "define the following properties at the same time: "
                    "['image', 'imageRef'].")
         self.stub_ImageConstraint_validate()
         stack = utils.parse_stack(self.t, stack_name=stack_name)
         vp = stack.t['Resources']['volume2']['Properties']
         vp.pop('size')
         vp.update(combinations)
-        ex = self.assertRaises(exception.ResourcePropertyConflict,
+        ex = self.assertRaises(exception.StackValidationFailed,
                                stack.get, 'volume2')
         self.assertEqual(err_msg, six.text_type(ex))
 
@@ -1157,7 +1211,8 @@ class CinderVolumeTest(vt_base.BaseVolumeTest):
             size=1, availability_zone=None,
             description='test_description',
             name='test_name',
-            multiattach=False
+            multiattach=False,
+            metadata={}
         ).AndReturn(vt_base.FakeVolume('creating'))
         fv = vt_base.FakeVolume('available')
         self.cinder_fc.volumes.get(fv.id).AndReturn(fv)
