@@ -11,10 +11,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import copy
-
 from neutronclient.common import exceptions
 from neutronclient.v2_0 import client as neutronclient
+from oslo_config import cfg
 import six
 
 from heat.common import exception
@@ -105,16 +104,37 @@ class FirewallTest(common.HeatTestCase):
 
         self.stack = utils.parse_stack(snippet)
         resource_defns = self.stack.t.resource_definitions(self.stack)
+        self.fw_props = snippet['resources']['firewall']['properties']
         return firewall.Firewall(
             'firewall', resource_defns['firewall'], self.stack)
 
     def test_create(self):
         rsrc = self.create_firewall()
+        neutronclient.Client.show_firewall('5678').AndReturn(
+            {'firewall': {'status': 'ACTIVE'}})
         self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         self.assertEqual((rsrc.CREATE, rsrc.COMPLETE), rsrc.state)
         self.m.VerifyAll()
 
+    def test_create_failed_error_status(self):
+        cfg.CONF.set_override('action_retry_limit', 0, enforce_type=True)
+        rsrc = self.create_firewall()
+        neutronclient.Client.show_firewall('5678').AndReturn(
+            {'firewall': {'status': 'PENDING_CREATE'}})
+        neutronclient.Client.show_firewall('5678').AndReturn(
+            {'firewall': {'status': 'ERROR'}})
+        self.m.ReplayAll()
+
+        error = self.assertRaises(exception.ResourceFailure,
+                                  scheduler.TaskRunner(rsrc.create))
+        self.assertEqual(
+            'ResourceInError: resources.firewall: '
+            'Went to status ERROR due to "Error in Firewall"',
+            six.text_type(error))
+        self.assertEqual((rsrc.CREATE, rsrc.FAILED), rsrc.state)
+        self.m.VerifyAll()
+
     def test_create_failed(self):
         neutronclient.Client.create_firewall({
             'firewall': {
@@ -140,11 +160,14 @@ class FirewallTest(common.HeatTestCase):
         self.m.VerifyAll()
 
     def test_delete(self):
+        rsrc = self.create_firewall()
+        neutronclient.Client.show_firewall('5678').AndReturn(
+            {'firewall': {'status': 'ACTIVE'}})
+
         neutronclient.Client.delete_firewall('5678')
         neutronclient.Client.show_firewall('5678').AndRaise(
             exceptions.NeutronClientException(status_code=404))
 
-        rsrc = self.create_firewall()
         self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         scheduler.TaskRunner(rsrc.delete)()
@@ -156,6 +179,8 @@ class FirewallTest(common.HeatTestCase):
             exceptions.NeutronClientException(status_code=404))
 
         rsrc = self.create_firewall()
+        neutronclient.Client.show_firewall('5678').AndReturn(
+            {'firewall': {'status': 'ACTIVE'}})
         self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         scheduler.TaskRunner(rsrc.delete)()
@@ -167,6 +192,8 @@ class FirewallTest(common.HeatTestCase):
             exceptions.NeutronClientException(status_code=400))
 
         rsrc = self.create_firewall()
+        neutronclient.Client.show_firewall('5678').AndReturn(
+            {'firewall': {'status': 'ACTIVE'}})
         self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         error = self.assertRaises(exception.ResourceFailure,
@@ -180,6 +207,8 @@ class FirewallTest(common.HeatTestCase):
 
     def test_attribute(self):
         rsrc = self.create_firewall()
+        neutronclient.Client.show_firewall('5678').AndReturn(
+            {'firewall': {'status': 'ACTIVE'}})
         neutronclient.Client.show_firewall('5678').MultipleTimes(
         ).AndReturn(
             {'firewall': {'admin_state_up': True,
@@ -195,6 +224,8 @@ class FirewallTest(common.HeatTestCase):
 
     def test_attribute_failed(self):
         rsrc = self.create_firewall()
+        neutronclient.Client.show_firewall('5678').AndReturn(
+            {'firewall': {'status': 'ACTIVE'}})
         self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         error = self.assertRaises(exception.InvalidTemplateAttribute,
@@ -206,19 +237,24 @@ class FirewallTest(common.HeatTestCase):
 
     def test_update(self):
         rsrc = self.create_firewall()
+        neutronclient.Client.show_firewall('5678').AndReturn(
+            {'firewall': {'status': 'ACTIVE'}})
         neutronclient.Client.update_firewall(
             '5678', {'firewall': {'admin_state_up': False}})
         self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
 
-        update_template = copy.deepcopy(rsrc.t)
-        update_template['Properties']['admin_state_up'] = False
+        props = self.fw_props.copy()
+        props['admin_state_up'] = False
+        update_template = rsrc.t.freeze(properties=props)
         scheduler.TaskRunner(rsrc.update, update_template)()
 
         self.m.VerifyAll()
 
     def test_update_with_value_specs(self):
         rsrc = self.create_firewall(value_specs=False)
+        neutronclient.Client.show_firewall('5678').AndReturn(
+            {'firewall': {'status': 'ACTIVE'}})
         neutronclient.Client.update_firewall(
             '5678', {'firewall': {'router_ids': ['router_1',
                                                  'router_2']}})
@@ -256,6 +292,7 @@ class FirewallPolicyTest(common.HeatTestCase):
 
         snippet = template_format.parse(firewall_policy_template)
         self.stack = utils.parse_stack(snippet)
+        self.tmpl = snippet
         resource_defns = self.stack.t.resource_definitions(self.stack)
         return firewall.FirewallPolicy(
             'firewall_policy', resource_defns['firewall_policy'], self.stack)
@@ -358,8 +395,9 @@ class FirewallPolicyTest(common.HeatTestCase):
         self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
 
-        update_template = copy.deepcopy(rsrc.t)
-        update_template['Properties']['firewall_rules'] = ['3', '4']
+        props = self.tmpl['resources']['firewall_policy']['properties'].copy()
+        props['firewall_rules'] = ['3', '4']
+        update_template = rsrc.t.freeze(properties=props)
         scheduler.TaskRunner(rsrc.update, update_template)()
 
         self.m.VerifyAll()
@@ -386,6 +424,7 @@ class FirewallRuleTest(common.HeatTestCase):
 
         snippet = template_format.parse(firewall_rule_template)
         self.stack = utils.parse_stack(snippet)
+        self.tmpl = snippet
         resource_defns = self.stack.t.resource_definitions(self.stack)
         return firewall.FirewallRule(
             'firewall_rule', resource_defns['firewall_rule'], self.stack)
@@ -401,7 +440,10 @@ class FirewallRuleTest(common.HeatTestCase):
         snippet = template_format.parse(firewall_rule_template)
         stack = utils.parse_stack(snippet)
         rsrc = stack['firewall_rule']
-        rsrc.t['Properties']['protocol'] = 'None'
+        props = dict(rsrc.properties)
+        props['protocol'] = 'None'
+        rsrc.t = rsrc.t.freeze(properties=props)
+        rsrc.reparse()
         self.assertRaises(exception.StackValidationFailed, rsrc.validate)
 
     def test_create_with_protocol_any(self):
@@ -414,9 +456,9 @@ class FirewallRuleTest(common.HeatTestCase):
         self.m.ReplayAll()
 
         snippet = template_format.parse(firewall_rule_template)
+        snippet['resources']['firewall_rule']['properties']['protocol'] = 'any'
         stack = utils.parse_stack(snippet)
         rsrc = stack['firewall_rule']
-        rsrc.t['Properties']['protocol'] = 'any'
 
         scheduler.TaskRunner(rsrc.create)()
         self.assertEqual((rsrc.CREATE, rsrc.COMPLETE), rsrc.state)
@@ -514,8 +556,9 @@ class FirewallRuleTest(common.HeatTestCase):
         self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
 
-        update_template = copy.deepcopy(rsrc.t)
-        update_template['Properties']['protocol'] = 'icmp'
+        props = self.tmpl['resources']['firewall_rule']['properties'].copy()
+        props['protocol'] = 'icmp'
+        update_template = rsrc.t.freeze(properties=props)
         scheduler.TaskRunner(rsrc.update, update_template)()
 
         self.m.VerifyAll()
@@ -527,7 +570,8 @@ class FirewallRuleTest(common.HeatTestCase):
         self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         # update to 'any' protocol
-        update_template = copy.deepcopy(rsrc.t)
-        update_template['Properties']['protocol'] = 'any'
+        props = self.tmpl['resources']['firewall_rule']['properties'].copy()
+        props['protocol'] = 'any'
+        update_template = rsrc.t.freeze(properties=props)
         scheduler.TaskRunner(rsrc.update, update_template)()
         self.m.VerifyAll()
