@@ -224,7 +224,10 @@ class NeutronRouterTest(common.HeatTestCase):
         props['distributed'] = True
         stack = utils.parse_stack(t)
         rsrc = stack['router']
-        rsrc.t['Properties'].pop('l3_agent_ids')
+        update_props = props.copy()
+        del update_props['l3_agent_ids']
+        rsrc.t = rsrc.t.freeze(properties=update_props)
+        rsrc.reparse()
         exc = self.assertRaises(exception.ResourcePropertyConflict,
                                 rsrc.validate)
         self.assertIn('distributed, ha', six.text_type(exc))
@@ -309,18 +312,6 @@ class NeutronRouterTest(common.HeatTestCase):
                     "id": "3e46229d-8fce-4733-819a-b5fe630550f8"
                 }
             })
-        neutronclient.Client.show_router(
-            '3e46229d-8fce-4733-819a-b5fe630550f8').AndReturn({
-                "router": {
-                    "status": "ACTIVE",
-                    "external_gateway_info": None,
-                    "name": utils.PhysName(stack.name, 'router'),
-                    "admin_state_up": True,
-                    "tenant_id": "3e21026f2dc94372b105808c0e721661",
-                    "routes": [],
-                    "id": "3e46229d-8fce-4733-819a-b5fe630550f8"
-                }
-            })
 
         # Update script
         neutronclient.Client.list_l3_agent_hosting_routers(
@@ -689,7 +680,7 @@ class NeutronRouterTest(common.HeatTestCase):
         ex = self.assertRaises(exception.PropertyUnspecifiedError,
                                res.validate)
         self.assertEqual("At least one of the following properties "
-                         "must be specified: subnet, port",
+                         "must be specified: subnet, port.",
                          six.text_type(ex))
         self.m.VerifyAll()
 
@@ -942,11 +933,12 @@ class NeutronRouterTest(common.HeatTestCase):
         stack = utils.parse_stack(t)
         rsrc = self.create_router(t, stack, 'router')
 
-        update_template = copy.deepcopy(rsrc.t)
-        update_template['Properties']['external_gateway_info'] = {
+        props = t['resources']['router']['properties'].copy()
+        props['external_gateway_info'] = {
             "network": "other_public",
             "enable_snat": False
         }
+        update_template = rsrc.t.freeze(properties=props)
         scheduler.TaskRunner(rsrc.update, update_template)()
         self.assertEqual((rsrc.UPDATE, rsrc.COMPLETE), rsrc.state)
 
