@@ -12,7 +12,6 @@
 #    under the License.
 
 import copy
-import mox
 from neutronclient.common import exceptions as qe
 from neutronclient.neutron import v2_0 as neutronV20
 from neutronclient.v2_0 import client as neutronclient
@@ -20,8 +19,9 @@ import six
 
 from heat.common import exception
 from heat.common import template_format
-from heat.engine.cfn import functions as cfn_funcs
 from heat.engine.clients.os import neutron
+from heat.engine.hot import functions as hot_funcs
+from heat.engine import resource
 from heat.engine.resources.openstack.neutron import subnet
 from heat.engine import rsrc_defn
 from heat.engine import scheduler
@@ -105,9 +105,10 @@ class NeutronSubnetTest(common.HeatTestCase):
         self.m.StubOutWithMock(neutronclient.Client, 'delete_subnet')
         self.m.StubOutWithMock(neutronclient.Client, 'show_subnet')
         self.m.StubOutWithMock(neutronclient.Client, 'update_subnet')
-        self.m.StubOutWithMock(neutronV20, 'find_resourceid_by_name_or_id')
         self.patchobject(neutron.NeutronClientPlugin, 'has_extension',
                          return_value=True)
+        self.patchobject(neutronV20, 'find_resourceid_by_name_or_id',
+                         return_value='fc68ea2c-b60b-4b4f-bd82-94ec81110766')
 
     def create_subnet(self, t, stack, resource_name):
         resource_defns = stack.t.resource_definitions(stack)
@@ -251,12 +252,6 @@ class NeutronSubnetTest(common.HeatTestCase):
                 "tenant_id": "c1210485b2424d48804aad5d39c61b8f"
             }
         }
-        neutronV20.find_resourceid_by_name_or_id(
-            mox.IsA(neutronclient.Client),
-            'subnetpool',
-            'fc68ea2c-b60b-4b4f-bd82-94ec81110766',
-            cmd_resource=None,
-        ).MultipleTimes().AndReturn('fc68ea2c-b60b-4b4f-bd82-94ec81110766')
         neutronclient.Client.create_subnet({
             'subnet': {
                 'network_id': 'fc68ea2c-b60b-4b4f-bd82-94ec81110766',
@@ -274,9 +269,6 @@ class NeutronSubnetTest(common.HeatTestCase):
             }
         }).AndReturn(subnet_dict)
 
-        neutronclient.Client.show_subnet(
-            '91e47a57-7508-46fe-afc9-fc454e8580e1').AndReturn(subnet_dict)
-
         neutronclient.Client.delete_subnet(
             '91e47a57-7508-46fe-afc9-fc454e8580e1'
         ).AndReturn(None)
@@ -405,8 +397,6 @@ class NeutronSubnetTest(common.HeatTestCase):
             '91e47a57-7508-46fe-afc9-fc454e8580e1').AndReturn(sn)
         neutronclient.Client.show_subnet(
             '91e47a57-7508-46fe-afc9-fc454e8580e1').AndReturn(sn)
-        neutronclient.Client.show_subnet(
-            '91e47a57-7508-46fe-afc9-fc454e8580e1').AndReturn(sn)
 
         # Delete script
         neutronclient.Client.delete_subnet(
@@ -645,13 +635,9 @@ class NeutronSubnetTest(common.HeatTestCase):
                          "supported for ipv4.", six.text_type(ex))
 
     def test_validate_both_subnetpool_cidr(self):
-        neutronV20.find_resourceid_by_name_or_id(
-            mox.IsA(neutronclient.Client),
-            'subnetpool',
-            'new_pool',
-            cmd_resource=None,
-        ).AndReturn('new_pool')
-        self.m.ReplayAll()
+        self.patchobject(neutronV20, 'find_resourceid_by_name_or_id',
+                         return_value='new_pool')
+
         t = template_format.parse(neutron_template)
         props = t['resources']['sub_net']['properties']
         props['subnetpool'] = 'new_pool'
@@ -677,9 +663,48 @@ class NeutronSubnetTest(common.HeatTestCase):
         ex = self.assertRaises(exception.PropertyUnspecifiedError,
                                rsrc.validate)
         msg = ("At least one of the following properties must be specified: "
-               "subnetpool, cidr")
+               "subnetpool, cidr.")
         self.assertEqual(msg, six.text_type(ex))
 
+    def test_validate_subnetpool_ref_with_cidr(self):
+        t = template_format.parse(neutron_template)
+        props = t['resources']['sub_net']['properties']
+        props['subnetpool'] = {'get_resource': 'subnetpool'}
+        props = t['resources']['sub_net']['properties']
+        stack = utils.parse_stack(t)
+        snippet = rsrc_defn.ResourceDefinition('subnetpool',
+                                               'OS::Neutron::SubnetPool')
+        res = resource.Resource('subnetpool', snippet, stack)
+        stack.add_resource(res)
+        self.patchobject(stack['subnetpool'], 'FnGetRefId',
+                         return_value=None)
+        self.patchobject(stack['net'], 'FnGetRefId',
+                         return_value='fc68ea2c-b60b-4b4f-bd82-94ec81110766')
+        rsrc = stack['sub_net']
+        ex = self.assertRaises(exception.ResourcePropertyConflict,
+                               rsrc.validate)
+        msg = ("Cannot define the following properties at the same time: "
+               "subnetpool, cidr.")
+        self.assertEqual(msg, six.text_type(ex))
+
+    def test_validate_subnetpool_ref_no_cidr(self):
+        t = template_format.parse(neutron_template)
+        props = t['resources']['sub_net']['properties']
+        del props['cidr']
+        props['subnetpool'] = {'get_resource': 'subnetpool'}
+        props = t['resources']['sub_net']['properties']
+        stack = utils.parse_stack(t)
+        snippet = rsrc_defn.ResourceDefinition('subnetpool',
+                                               'OS::Neutron::SubnetPool')
+        res = resource.Resource('subnetpool', snippet, stack)
+        stack.add_resource(res)
+        self.patchobject(stack['subnetpool'], 'FnGetRefId',
+                         return_value=None)
+        self.patchobject(stack['net'], 'FnGetRefId',
+                         return_value='fc68ea2c-b60b-4b4f-bd82-94ec81110766')
+        rsrc = stack['sub_net']
+        self.assertIsNone(rsrc.validate())
+
     def test_validate_both_prefixlen_cidr(self):
         t = template_format.parse(neutron_template)
         props = t['resources']['sub_net']['properties']
@@ -715,6 +740,6 @@ class NeutronSubnetTest(common.HeatTestCase):
         rsrc = stack['subnet']
         stack.create()
 
-        self.assertEqual(cfn_funcs.ResourceRef(stack, 'get_resource', 'net'),
+        self.assertEqual(hot_funcs.GetResource(stack, 'get_resource', 'net'),
                          rsrc.properties.get('network'))
         self.assertIsNone(rsrc.properties.get('network_id'))
