@@ -37,6 +37,7 @@ resources:
     properties:
       name: SenlinNode
       profile: fake_profile
+      cluster: fake_cluster
       metadata:
         foo: bar
 """
@@ -49,8 +50,8 @@ class FakeNode(object):
         self.id = id
         self.name = "SenlinNode"
         self.metadata = {'foo': 'bar'}
-        self.profile_id = "fake_profile"
-        self.cluster_id = "fake_cluster"
+        self.profile_id = "fake_profile_id"
+        self.cluster_id = "fake_cluster_id"
         self.details = {'id': 'physical_object_id'}
         self.location = "actions/fake_action"
 
@@ -70,6 +71,12 @@ class SenlinNodeTest(common.HeatTestCase):
     def setUp(self):
         super(SenlinNodeTest, self).setUp()
         self.senlin_mock = mock.MagicMock()
+        self.senlin_mock.get_profile.return_value = mock.Mock(
+            id='fake_profile_id'
+        )
+        self.senlin_mock.get_cluster.return_value = mock.Mock(
+            id='fake_cluster_id'
+        )
         self.patchobject(sn.Node, 'client', return_value=self.senlin_mock)
         self.patchobject(senlin.SenlinClientPlugin, 'client',
                          return_value=self.senlin_mock)
@@ -97,8 +104,9 @@ class SenlinNodeTest(common.HeatTestCase):
         self._create_node()
         expect_kwargs = {
             'name': 'SenlinNode',
-            'profile_id': 'fake_profile',
+            'profile_id': 'fake_profile_id',
             'metadata': {'foo': 'bar'},
+            'cluster_id': 'fake_cluster_id',
         }
         self.senlin_mock.create_node.assert_called_once_with(
             **expect_kwargs)
@@ -135,6 +143,12 @@ class SenlinNodeTest(common.HeatTestCase):
 
     def test_node_update_profile(self):
         node = self._create_node()
+        # Mock translate rules
+        self.senlin_mock.get_profile.side_effect = [
+            mock.Mock(id='new_profile_id'),
+            mock.Mock(id='fake_profile_id'),
+            mock.Mock(id='new_profile_id'),
+        ]
         new_t = copy.deepcopy(self.t)
         props = new_t['resources']['senlin-node']['properties']
         props['profile'] = 'new_profile'
@@ -146,13 +160,39 @@ class SenlinNodeTest(common.HeatTestCase):
         scheduler.TaskRunner(node.update, new_node)()
         self.assertEqual((node.UPDATE, node.COMPLETE), node.state)
         node_update_kwargs = {
-            'profile_id': 'new_profile',
+            'profile_id': 'new_profile_id',
             'name': 'new_name'
         }
         self.senlin_mock.update_node.assert_called_once_with(
-            node.resource_id, **node_update_kwargs)
+            node=self.fake_node, **node_update_kwargs)
         self.assertEqual(2, self.senlin_mock.get_action.call_count)
 
+    def test_node_update_cluster(self):
+        node = self._create_node()
+        # Mock translate rules
+        self.senlin_mock.get_cluster.side_effect = [
+            mock.Mock(id='new_cluster_id'),
+            mock.Mock(id='fake_cluster_id'),
+            mock.Mock(id='new_cluster_id'),
+        ]
+        new_t = copy.deepcopy(self.t)
+        props = new_t['resources']['senlin-node']['properties']
+        props['cluster'] = 'new_cluster'
+        rsrc_defns = template.Template(new_t).resource_definitions(self.stack)
+        new_node = rsrc_defns['senlin-node']
+        self.senlin_mock.cluster_del_nodes.return_value = {
+            'action': 'remove_node_from_cluster'
+        }
+        self.senlin_mock.cluster_add_nodes.return_value = {
+            'action': 'add_node_to_cluster'
+        }
+        scheduler.TaskRunner(node.update, new_node)()
+        self.assertEqual((node.UPDATE, node.COMPLETE), node.state)
+        self.senlin_mock.cluster_del_nodes.assert_called_once_with(
+            cluster='fake_cluster_id', nodes=[node.resource_id])
+        self.senlin_mock.cluster_add_nodes.assert_called_once_with(
+            cluster='new_cluster_id', nodes=[node.resource_id])
+
     def test_node_update_failed(self):
         node = self._create_node()
         new_t = copy.deepcopy(self.t)
@@ -179,8 +219,8 @@ class SenlinNodeTest(common.HeatTestCase):
             'status_reason': 'Unknown',
             'name': 'SenlinNode',
             'metadata': {'foo': 'bar'},
-            'profile_id': 'fake_profile',
-            'cluster_id': 'fake_cluster'
+            'profile_id': 'fake_profile_id',
+            'cluster_id': 'fake_cluster_id'
         }
         node = self._create_node()
         self.assertEqual(excepted_show,
@@ -189,3 +229,14 @@ class SenlinNodeTest(common.HeatTestCase):
                          node._resolve_attribute('details'))
         self.senlin_mock.get_node.assert_called_with(
             node.resource_id, details=True)
+
+    def test_node_get_live_state(self):
+        expected_reality = {
+            'name': 'SenlinNode',
+            'metadata': {'foo': 'bar'},
+            'profile': 'fake_profile_id',
+            'cluster': 'fake_cluster_id'
+        }
+        node = self._create_node()
+        reality = node.get_live_state(node.properties)
+        self.assertEqual(expected_reality, reality)
