@@ -15,7 +15,7 @@ import uuid
 
 import mock
 import six
-from troveclient.openstack.common.apiclient import exceptions as troveexc
+from troveclient import exceptions as troveexc
 from troveclient.v1 import users
 
 from heat.common import exception
@@ -185,11 +185,8 @@ class OSDBInstanceTest(common.HeatTestCase):
         self.m.VerifyAll()
 
     def test_create_failed(self):
-        mock_stack = mock.Mock()
-        mock_stack.db_resource_get.return_value = None
-        mock_stack.has_cache_data.return_value = False
-        res_def = mock.Mock(spec=rsrc_defn.ResourceDefinition)
-        osdb_res = os_database.OSDBInstance("test", res_def, mock_stack)
+        t = template_format.parse(db_template)
+        osdb_res = self._setup_test_clouddbinstance('dbinstance_create', t)
 
         trove_mock = mock.Mock()
         self.patchobject(osdb_res, 'client', return_value=trove_mock)
