@@ -13,6 +13,7 @@
 
 import os
 
+from keystoneauth1 import loading as ks_loading
 import mock
 from oslo_config import cfg
 from oslo_config import fixture as config_fixture
@@ -144,9 +145,6 @@ class TestRequestContext(common.HeatTestCase):
         """
         cfg.CONF.set_override('auth_uri', 'http://xyz',
                               group='clients_keystone', enforce_type=True)
-        importutils.import_module('keystonemiddleware.auth_token')
-        cfg.CONF.set_override('auth_uri', 'http://abc/v2.0',
-                              group='keystone_authtoken', enforce_type=True)
         policy_check = 'heat.common.policy.Enforcer.check_is_admin'
         with mock.patch(policy_check) as pc:
             pc.return_value = False
@@ -188,27 +186,13 @@ class TestRequestContext(common.HeatTestCase):
             self.assertRaises(exception.AuthorizationFailure, getattr, ctx,
                               'keystone_v3_endpoint')
 
-    def test_create_trusts_auth_plugin_with_correct_user_domain_id(self):
-        importutils.import_module('keystonemiddleware.auth_token')
-        cfg.CONF.set_override('auth_uri', 'http://abc/v2.0',
-                              group='keystone_authtoken', enforce_type=True)
-        cfg.CONF.set_override('admin_user', 'heat',
-                              group='keystone_authtoken', enforce_type=True)
-        cfg.CONF.set_override('admin_password', 'password',
-                              group='keystone_authtoken', enforce_type=True)
-        policy_check = 'heat.common.policy.Enforcer.check_is_admin'
-        with mock.patch(policy_check) as pc:
-            pc.return_value = False
-            ctx = context.RequestContext(auth_url=None,
-                                         user_domain_id='non-default',
-                                         username='test')
-            with mock.patch('keystoneauth1.identity.generic.Password') as ps:
-                ctx.trusts_auth_plugin
-                ps.assert_called_once_with(username='heat',
-                                           password='password',
-                                           user_domain_id='default',
-                                           auth_url='http://abc/v3',
-                                           trust_id=None)
+    def test_get_trust_context_auth_plugin_unauthorized(self):
+        self.ctx['trust_id'] = 'trust_id'
+        ctx = context.RequestContext.from_dict(self.ctx)
+        self.patchobject(ks_loading, 'load_auth_from_conf_options',
+                         return_value=None)
+        self.assertRaises(exception.AuthorizationFailure, getattr,
+                          ctx, 'auth_plugin')
 
     def test_cache(self):
         ctx = context.RequestContext.from_dict(self.ctx)
