@@ -21,7 +21,6 @@ from heat.engine import stack as parser
 from heat.engine import template as templatem
 from heat.objects import raw_template as raw_template_object
 from heat.objects import resource as resource_objects
-from heat.objects import snapshot as snapshot_objects
 from heat.objects import stack as stack_object
 from heat.objects import sync_point as sync_point_object
 from heat.rpc import worker_client
@@ -553,37 +552,6 @@ class StackConvergenceCreateUpdateDeleteTest(common.HeatTestCase):
         self.assertTrue(mock_syncpoint_del.called)
         self.assertTrue(mock_ccu.called)
 
-    def test_snapshot_delete(self, mock_cr):
-        tmpl = {'HeatTemplateFormatVersion': '2012-12-12',
-                'Resources': {'R1': {'Type': 'GenericResourceType'}}}
-        stack = parser.Stack(utils.dummy_context(), 'updated_time_test',
-                             templatem.Template(tmpl))
-        stack.current_traversal = 'prev_traversal'
-        stack.action, stack.status = stack.CREATE, stack.COMPLETE
-        stack.store()
-        stack.thread_group_mgr = tools.DummyThreadGroupManager()
-        snapshot_values = {
-            'stack_id': stack.id,
-            'name': 'fake_snapshot',
-            'tenant': stack.context.tenant_id,
-            'status': 'COMPLETE',
-            'data': None
-        }
-        snapshot_objects.Snapshot.create(stack.context, snapshot_values)
-
-        # Ensure that snapshot is not deleted on stack update
-        stack.converge_stack(template=stack.t, action=stack.UPDATE)
-        db_snapshot_obj = snapshot_objects.Snapshot.get_all(
-            stack.context, stack.id)
-        self.assertEqual('fake_snapshot', db_snapshot_obj[0].name)
-        self.assertEqual(stack.id, db_snapshot_obj[0].stack_id)
-
-        # Ensure that snapshot is deleted on stack delete
-        stack.converge_stack(template=stack.t, action=stack.DELETE)
-        self.assertEqual([], snapshot_objects.Snapshot.get_all(
-            stack.context, stack.id))
-        self.assertTrue(mock_cr.called)
-
 
 @mock.patch.object(parser.Stack, '_persist_state')
 class TestConvgStackStateSet(common.HeatTestCase):
@@ -663,15 +631,16 @@ class TestConvgStackStateSet(common.HeatTestCase):
         self.assertIsNone(ret_val)
 
     def test_state_set_stack_restore(self, mock_ps):
+        mock_ps.return_value = 'updated'
         ret_val = self.stack.state_set(
             self.stack.RESTORE, self.stack.IN_PROGRESS, 'Restore started')
         self.assertTrue(mock_ps.called)
-        self.assertIsNone(ret_val)
+        self.assertEqual('updated', ret_val)
         mock_ps.reset_mock()
         ret_val = self.stack.state_set(
             self.stack.RESTORE, self.stack.COMPLETE, 'Restore complete')
-        self.assertFalse(mock_ps.called)
-        self.assertIsNone(ret_val)
+        self.assertTrue(mock_ps.called)
+        self.assertEqual('updated', ret_val)
 
 
 class TestConvgStackRollback(common.HeatTestCase):
