@@ -271,9 +271,14 @@ class ProviderTemplateTest(common.HeatTestCase):
                                                   "DummyResource2")
         temp_res = template_resource.TemplateResource('test_t_res',
                                                       definition, stack)
-        nested = mock.Mock()
-        nested.outputs = {'Blarg': {'Value': 'fluffy'}}
-        temp_res._nested = nested
+        temp_res.resource_id = 'dummy_id'
+        temp_res.nested_identifier = mock.Mock()
+        temp_res.nested_identifier.return_value = {'foo': 'bar'}
+
+        temp_res._rpc_client = mock.MagicMock()
+        output = {'outputs': [{'output_key': 'Blarg',
+                               'output_value': 'fluffy'}]}
+        temp_res._rpc_client.show_stack.return_value = [output]
         self.assertRaises(exception.InvalidTemplateAttribute,
                           temp_res.FnGetAtt, 'Foo')
 
@@ -305,13 +310,16 @@ class ProviderTemplateTest(common.HeatTestCase):
                                                   "DummyResource")
         temp_res = template_resource.TemplateResource('test_t_res',
                                                       definition, stack)
+        temp_res.resource_id = 'dummy_id'
         self.assertIsNone(temp_res.validate())
-        nested = mock.Mock()
-        nested.outputs = {'Foo': {'Value': 'not-this',
-                                  'error_msg': 'it is all bad'}}
-        nested.output.return_value = None
-        temp_res._nested = nested
-        self.assertRaises(exception.InvalidTemplateAttribute,
+        temp_res.nested_identifier = mock.Mock()
+        temp_res.nested_identifier.return_value = {'foo': 'bar'}
+
+        temp_res._rpc_client = mock.MagicMock()
+        output = {'outputs': [{'output_key': 'Foo', 'output_value': None,
+                               'output_error': 'it is all bad'}]}
+        temp_res._rpc_client.show_stack.return_value = [output]
+        self.assertRaises(exception.TemplateOutputError,
                           temp_res.FnGetAtt, 'Foo')
 
     def test_properties_normal(self):
@@ -932,6 +940,7 @@ class TemplateDataTest(common.HeatTestCase):
 
     def test_template_data_in_update_without_template_file(self):
         self.res.action = self.res.UPDATE
+        self.res.resource_id = 'dummy_id'
         self.res.nested = mock.MagicMock()
         self.res.get_template_file = mock.Mock(
             side_effect=exception.NotFound(
@@ -942,6 +951,7 @@ class TemplateDataTest(common.HeatTestCase):
     def test_template_data_in_create_without_template_file(self):
         self.res.action = self.res.CREATE
         self.res.nested = mock.MagicMock()
+        self.res.resource_id = 'dummy_id'
         self.res.get_template_file = mock.Mock(
             side_effect=exception.NotFound(
                 msg_fmt='Could not fetch remote template '
