@@ -13,15 +13,16 @@
 
 import datetime
 
-from keystoneclient import exceptions as kc_exceptions
+from keystoneauth1 import exceptions as kc_exceptions
 import mock
 import six
 from six.moves.urllib import parse as urlparse
 
 from heat.common import exception
 from heat.common import template_format
-from heat.engine.clients.os.heat_plugin import HeatClientPlugin
-from heat.engine.clients.os.swift import SwiftClientPlugin
+from heat.db.sqlalchemy import models
+from heat.engine.clients.os import heat_plugin
+from heat.engine.clients.os import swift
 from heat.engine import scheduler
 from heat.engine import stack as stk
 from heat.engine import template
@@ -95,7 +96,7 @@ class SignalTest(common.HeatTestCase):
 
         tpl = template.Template(template_format.parse(template_string))
         ctx = utils.dummy_context()
-        ctx.tenant_id = 'test_tenant'
+        ctx.tenant = 'test_tenant'
         stack = stk.Stack(ctx, stack_name, tpl, disable_rollback=True)
         with utils.UUIDStub(stack_id):
             stack.store()
@@ -120,8 +121,9 @@ class SignalTest(common.HeatTestCase):
         self.assertEqual('anaccesskey', rs_data.get('access_key'))
         self.assertEqual('verysecret', rs_data.get('secret_key'))
         self.assertEqual('1234', rs_data.get('user_id'))
+        self.assertEqual('password', rs_data.get('password'))
         self.assertEqual(rsrc.resource_id, rs_data.get('user_id'))
-        self.assertEqual(4, len(list(six.iterkeys(rs_data))))
+        self.assertEqual(5, len(rs_data))
 
     def test_get_user_id(self):
         # Setup
@@ -147,7 +149,7 @@ class SignalTest(common.HeatTestCase):
             rsrc, 'user_id')
         self.assertEqual('1234', rsrc._get_user_id())
 
-    @mock.patch.object(HeatClientPlugin, 'get_heat_cfn_url')
+    @mock.patch.object(heat_plugin.HeatClientPlugin, 'get_heat_cfn_url')
     def test_FnGetAtt_alarm_url(self, mock_get):
         # Setup
         stack_id = stack_name = 'FnGetAtt-alarm-url'
@@ -205,7 +207,7 @@ class SignalTest(common.HeatTestCase):
 
         # Test
         first_url = rsrc.FnGetAtt('signal')
-        self.assertTrue('alarm_url' in first_url)
+        self.assertIn('alarm_url', first_url)
         mock_has.assert_called_once_with('signal_handler')
         mock_has.reset_mock()  # reset the count for the next check
 
@@ -213,7 +215,7 @@ class SignalTest(common.HeatTestCase):
         mock_has.assert_called_once_with('signal_handler')
         self.assertEqual(second_url, 'cached')
 
-    @mock.patch.object(HeatClientPlugin, 'get_heat_url')
+    @mock.patch.object(heat_plugin.HeatClientPlugin, 'get_heat_url')
     def test_FnGetAtt_heat_signal(self, mock_get):
         # Setup
         stack = self._create_stack(TEMPLATE_HEAT_TEMPLATE_SIGNAL)
@@ -259,7 +261,8 @@ class SignalTest(common.HeatTestCase):
         mock_has.assert_called_once_with('signal_handler')
         self.assertEqual(second_url, 'cached')
 
-    def test_FnGetAtt_zaqar_signal(self):
+    @mock.patch('zaqarclient.queues.v2.queues.Queue.signed_url')
+    def test_FnGetAtt_zaqar_signal(self, mock_signed_url):
         # Setup
         stack = self._create_stack(TEMPLATE_ZAQAR_SIGNAL)
         rsrc = stack['signal_handler']
@@ -276,10 +279,14 @@ class SignalTest(common.HeatTestCase):
         self.assertIn('username', signal)
         self.assertIn('password', signal)
         self.assertIn('queue_id', signal)
+        mock_signed_url.assert_called_once_with(
+            ['messages'], methods=['GET', 'DELETE'])
 
     @mock.patch.object(stk.Stack, 'cache_data_resource_attribute')
     @mock.patch.object(stk.Stack, 'has_cache_data')
-    def test_FnGetAtt_zaqar_signal_is_cached(self, mock_has, mock_get):
+    @mock.patch('zaqarclient.queues.v2.queues.Queue.signed_url')
+    def test_FnGetAtt_zaqar_signal_is_cached(self, mock_signed_url, mock_has,
+                                             mock_get):
         # Setup
         mock_has.return_value = False
         stack = self._create_stack(TEMPLATE_ZAQAR_SIGNAL)
@@ -304,7 +311,7 @@ class SignalTest(common.HeatTestCase):
 
     @mock.patch('swiftclient.client.Connection.put_container')
     @mock.patch('swiftclient.client.Connection.put_object')
-    @mock.patch.object(SwiftClientPlugin, 'get_temp_url')
+    @mock.patch.object(swift.SwiftClientPlugin, 'get_temp_url')
     def test_FnGetAtt_swift_signal(self, mock_get_url,
                                    mock_put_object, mock_put_container):
         # Setup
@@ -327,7 +334,7 @@ class SignalTest(common.HeatTestCase):
 
     @mock.patch('swiftclient.client.Connection.put_container')
     @mock.patch('swiftclient.client.Connection.put_object')
-    @mock.patch.object(SwiftClientPlugin, 'get_temp_url')
+    @mock.patch.object(swift.SwiftClientPlugin, 'get_temp_url')
     @mock.patch.object(stk.Stack, 'cache_data_resource_attribute')
     @mock.patch.object(stk.Stack, 'has_cache_data')
     def test_FnGetAtt_swift_signal_is_cached(self, mock_has, mock_get,
@@ -349,7 +356,7 @@ class SignalTest(common.HeatTestCase):
 
         # Test
         first_url = rsrc.FnGetAtt('signal')
-        self.assertTrue('alarm_url' in first_url)
+        self.assertIn('alarm_url', first_url)
         mock_has.assert_called_once_with('signal_handler')
         mock_has.reset_mock()  # reset the count for the next check
 
@@ -362,7 +369,7 @@ class SignalTest(common.HeatTestCase):
         self.assertEqual(1, mock_put_object.call_count)
         self.assertEqual(1, mock_get_url.call_count)
 
-    @mock.patch.object(HeatClientPlugin, 'get_heat_cfn_url')
+    @mock.patch.object(heat_plugin.HeatClientPlugin, 'get_heat_cfn_url')
     def test_FnGetAtt_delete(self, mock_get):
         # Setup
         mock_get.return_value = 'http://server.test:8000/v1'
@@ -384,7 +391,7 @@ class SignalTest(common.HeatTestCase):
 
         self.assertEqual(2, mock_get.call_count)
 
-    @mock.patch.object(HeatClientPlugin, 'get_heat_url')
+    @mock.patch.object(heat_plugin.HeatClientPlugin, 'get_heat_url')
     def test_FnGetAtt_heat_signal_delete(self, mock_get):
         # Setup
         mock_get.return_value = 'http://server.test:8004/v1'
@@ -411,7 +418,7 @@ class SignalTest(common.HeatTestCase):
     @mock.patch('swiftclient.client.Connection.delete_container')
     @mock.patch('swiftclient.client.Connection.delete_object')
     @mock.patch('swiftclient.client.Connection.get_container')
-    @mock.patch.object(SwiftClientPlugin, 'get_temp_url')
+    @mock.patch.object(swift.SwiftClientPlugin, 'get_temp_url')
     @mock.patch('swiftclient.client.Connection.head_container')
     @mock.patch('swiftclient.client.Connection.put_container')
     @mock.patch('swiftclient.client.Connection.put_object')
@@ -454,7 +461,8 @@ class SignalTest(common.HeatTestCase):
         self.assertEqual(1, mock_delete_container.call_count)
         self.assertEqual(1, mock_head.call_count)
 
-    def test_FnGetAtt_zaqar_signal_delete(self):
+    @mock.patch('zaqarclient.queues.v2.queues.Queue.signed_url')
+    def test_FnGetAtt_zaqar_signal_delete(self, mock_signed_url):
         # Setup
         stack = self._create_stack(TEMPLATE_ZAQAR_SIGNAL)
 
@@ -520,26 +528,30 @@ class SignalTest(common.HeatTestCase):
         mock_handle.assert_called_once_with(test_d)
         self.assertTrue(result)
 
-    @mock.patch.object(generic_resource.SignalResource, '_add_event')
     @mock.patch.object(generic_resource.SignalResource, 'handle_signal')
-    def test_signal_no_action(self, mock_handle, mock_add):
+    def test_handle_signal_no_reraise_deleted(self, mock_handle):
         # Setup
         test_d = {'Data': 'foo', 'Reason': 'bar',
                   'Status': 'SUCCESS', 'UniqueId': '123'}
 
         stack = self._create_stack(TEMPLATE_CFN_SIGNAL)
 
-        mock_handle.side_effect = exception.NoActionRequired()
+        mock_handle.side_effect = exception.ResourceNotAvailable(
+            resource_name='test')
         rsrc = stack['signal_handler']
 
         self.assertEqual((rsrc.CREATE, rsrc.COMPLETE), rsrc.state)
-        self.assertTrue(rsrc.requires_deferred_auth)
 
-        # Test
-        mock_add.reset_mock()  # clean up existing calls before test
-        rsrc.signal(details=test_d)
+        # In the midst of handling a signal, an update happens on the
+        # db resource concurrently, deleting it
+
+        # Test exception not re-raised in DELETE case
+        res_obj = stack.context.session.query(
+            models.Resource).get(rsrc.id)
+        res_obj.update({'action': 'DELETE'})
+        rsrc._db_res_is_deleted = True
+        rsrc._handle_signal(details=test_d)
         mock_handle.assert_called_once_with(test_d)
-        mock_add.assert_not_called()
 
     @mock.patch.object(generic_resource.SignalResource, '_add_event')
     def test_signal_different_reason_types(self, mock_add):
