@@ -523,6 +523,12 @@ class StackResourceTest(StackResourceBaseTest):
         need update.
         """
         self.parent_resource.action = self.parent_resource.CREATE
+
+        self.parent_resource._rpc_client = mock.MagicMock()
+        self.parent_resource._rpc_client.show_stack.return_value = [
+            {'stack_action': self.parent_resource.CREATE,
+             'stack_status': self.parent_resource.COMPLETE}]
+
         need_update = self.parent_resource._needs_update(
             self.parent_resource.t,
             self.parent_resource.t,
@@ -566,12 +572,8 @@ class StackResourceTest(StackResourceBaseTest):
                           self.parent_resource.properties,
                           self.parent_resource)
 
-    def test_need_update_in_check_failed_state_for_nested_resource(self):
-        """Test the resource should need replacement.
-
-        The resource in check_failed state should need update with
-        UpdateReplace.
-        """
+    def test_need_update_in_check_failed_state_after_stack_check(self):
+        self.parent_resource.resource_id = 'fake_id'
         self.parent_resource.state_set(self.parent_resource.CHECK,
                                        self.parent_resource.FAILED)
         self.nested = mock.MagicMock()
@@ -579,6 +581,32 @@ class StackResourceTest(StackResourceBaseTest):
         self.parent_resource.nested = mock.MagicMock(return_value=self.nested)
         self.parent_resource._nested = self.nested
 
+        self.parent_resource._rpc_client = mock.MagicMock()
+        self.parent_resource._rpc_client.show_stack.return_value = [
+            {'stack_action': self.parent_resource.CHECK,
+             'stack_status': self.parent_resource.FAILED}]
+
+        self.assertTrue(
+            self.parent_resource._needs_update(self.parent_resource.t,
+                                               self.parent_resource.t,
+                                               self.parent_resource.properties,
+                                               self.parent_resource.properties,
+                                               self.parent_resource))
+
+    def test_need_update_check_failed_state_after_mark_unhealthy(self):
+        self.parent_resource.resource_id = 'fake_id'
+        self.parent_resource.state_set(self.parent_resource.CHECK,
+                                       self.parent_resource.FAILED)
+        self.nested = mock.MagicMock()
+        self.nested.name = 'nested-stack'
+        self.parent_resource.nested = mock.MagicMock(return_value=self.nested)
+        self.parent_resource._nested = self.nested
+
+        self.parent_resource._rpc_client = mock.MagicMock()
+        self.parent_resource._rpc_client.show_stack.return_value = [
+            {'stack_action': self.parent_resource.CREATE,
+             'stack_status': self.parent_resource.COMPLETE}]
+
         self.assertRaises(resource.UpdateReplace,
                           self.parent_resource._needs_update,
                           self.parent_resource.t,
