@@ -90,7 +90,8 @@ def dummy_context(user='test_username', tenant_id='test_tenant_id',
 
 
 def parse_stack(t, params=None, files=None, stack_name=None,
-                stack_id=None, timeout_mins=None, cache_data=None):
+                stack_id=None, timeout_mins=None,
+                cache_data=None, tags=None):
     params = params or {}
     files = files or {}
     ctx = dummy_context()
@@ -100,7 +101,8 @@ def parse_stack(t, params=None, files=None, stack_name=None,
     if stack_name is None:
         stack_name = random_name()
     stk = stack.Stack(ctx, stack_name, templ, stack_id=stack_id,
-                      timeout_mins=timeout_mins, cache_data=cache_data)
+                      timeout_mins=timeout_mins,
+                      cache_data=cache_data, tags=tags)
     stk.store()
     return stk
 
